@@ -51,65 +51,79 @@ class PieceStorage;
 
 class DefaultPeerStorage : public PeerStorage {
 private:
-  SharedHandle<BtRuntime> btRuntime_;
-  SharedHandle<PieceStorage> pieceStorage_;
+  std::shared_ptr<BtRuntime> btRuntime_;
+  std::shared_ptr<PieceStorage> pieceStorage_;
   size_t maxPeerListSize_;
-  std::deque<SharedHandle<Peer> > peers_;
-  std::deque<SharedHandle<Peer> > droppedPeers_;
 
-  BtSeederStateChoke* seederStateChoke_;
-  BtLeecherStateChoke* leecherStateChoke_;
+  // This contains ip address and port pair and is used to ensure that
+  // no duplicate peers are stored.
+  std::set<std::pair<std::string, uint16_t>> uniqPeers_;
+  // Unused (not connected) peers, sorted by last added.
+  std::deque<std::shared_ptr<Peer>> unusedPeers_;
+  // The set of used peers. Some of them are not connected yet. To
+  // know it is connected or not, call Peer::isActive().
+  PeerSet usedPeers_;
+
+  std::deque<std::shared_ptr<Peer>> droppedPeers_;
+
+  std::unique_ptr<BtSeederStateChoke> seederStateChoke_;
+  std::unique_ptr<BtLeecherStateChoke> leecherStateChoke_;
 
   Timer lastTransferStatMapUpdated_;
 
-  std::map<std::string, time_t> badPeers_;
+  std::map<std::string, Timer> badPeers_;
   Timer lastBadPeerCleaned_;
 
-  bool isPeerAlreadyAdded(const SharedHandle<Peer>& peer);
+  bool isPeerAlreadyAdded(const std::shared_ptr<Peer>& peer);
+  void addUniqPeer(const std::shared_ptr<Peer>& peer);
+
+  void addDroppedPeer(const std::shared_ptr<Peer>& peer);
 
-  void addDroppedPeer(const SharedHandle<Peer>& peer);
 public:
   DefaultPeerStorage();
 
   virtual ~DefaultPeerStorage();
 
-  virtual bool addPeer(const SharedHandle<Peer>& peer);
+  // TODO We need addAndCheckoutPeer for incoming peers
+  virtual bool addPeer(const std::shared_ptr<Peer>& peer) CXX11_OVERRIDE;
 
-  virtual size_t countPeer() const;
+  virtual size_t countAllPeer() const CXX11_OVERRIDE;
 
-  virtual SharedHandle<Peer> getUnusedPeer();
+  std::shared_ptr<Peer> getPeer(const std::string& ipaddr, uint16_t port) const;
 
-  SharedHandle<Peer> getPeer(const std::string& ipaddr, uint16_t port) const;
+  virtual void
+  addPeer(const std::vector<std::shared_ptr<Peer>>& peers) CXX11_OVERRIDE;
 
-  virtual void addPeer(const std::vector<SharedHandle<Peer> >& peers);
+  const std::deque<std::shared_ptr<Peer>>& getUnusedPeers();
 
-  virtual const std::deque<SharedHandle<Peer> >& getPeers();
+  virtual const PeerSet& getUsedPeers() CXX11_OVERRIDE;
 
-  virtual const std::deque<SharedHandle<Peer> >& getDroppedPeers();
+  virtual const std::deque<std::shared_ptr<Peer>>&
+  getDroppedPeers() CXX11_OVERRIDE;
 
-  virtual bool isPeerAvailable();
+  virtual bool isPeerAvailable() CXX11_OVERRIDE;
 
-  virtual void getActivePeers(std::vector<SharedHandle<Peer> >& peers);
+  virtual bool isBadPeer(const std::string& ipaddr) CXX11_OVERRIDE;
 
-  virtual bool isBadPeer(const std::string& ipaddr);
+  virtual void addBadPeer(const std::string& ipaddr) CXX11_OVERRIDE;
 
-  virtual void addBadPeer(const std::string& ipaddr);
+  virtual std::shared_ptr<Peer> checkoutPeer(cuid_t cuid) CXX11_OVERRIDE;
 
-  virtual void returnPeer(const SharedHandle<Peer>& peer);
+  virtual void returnPeer(const std::shared_ptr<Peer>& peer) CXX11_OVERRIDE;
 
-  virtual bool chokeRoundIntervalElapsed();
+  virtual bool chokeRoundIntervalElapsed() CXX11_OVERRIDE;
 
-  virtual void executeChoke();
+  virtual void executeChoke() CXX11_OVERRIDE;
 
   void deleteUnusedPeer(size_t delSize);
 
-  void onErasingPeer(const SharedHandle<Peer>& peer);
+  void onErasingPeer(const std::shared_ptr<Peer>& peer);
 
-  void onReturningPeer(const SharedHandle<Peer>& peer);
+  void onReturningPeer(const std::shared_ptr<Peer>& peer);
 
-  void setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage);
+  void setPieceStorage(const std::shared_ptr<PieceStorage>& pieceStorage);
 
-  void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
+  void setBtRuntime(const std::shared_ptr<BtRuntime>& btRuntime);
 
   void setMaxPeerListSize(size_t maxPeerListSize)
   {
