@@ -44,23 +44,28 @@
 namespace aria2 {
 
 SimpleBtMessage::SimpleBtMessage(uint8_t id, const char* name)
-  : AbstractBtMessage(id, name)
-{}
+    : AbstractBtMessage(id, name)
+{
+}
 
-void SimpleBtMessage::send() {
-  if(isInvalidate() || !sendPredicate()) {
+void SimpleBtMessage::send()
+{
+  if (isInvalidate() || !sendPredicate()) {
     return;
   }
-  A2_LOG_INFO(fmt(MSG_SEND_PEER_MESSAGE,
-                  getCuid(),
-                  getPeer()->getIPAddress().c_str(),
-                  getPeer()->getPort(),
+  A2_LOG_INFO(fmt(MSG_SEND_PEER_MESSAGE, getCuid(),
+                  getPeer()->getIPAddress().c_str(), getPeer()->getPort(),
                   toString().c_str()));
   unsigned char* msg = createMessage();
   size_t msgLength = getMessageLength();
-  A2_LOG_DEBUG(fmt("msglength = %lu bytes",
-                   static_cast<unsigned long>(msgLength)));
+  A2_LOG_DEBUG(
+      fmt("msglength = %lu bytes", static_cast<unsigned long>(msgLength)));
   getPeerConnection()->pushBytes(msg, msgLength, getProgressUpdate());
 }
 
+std::unique_ptr<ProgressUpdate> SimpleBtMessage::getProgressUpdate()
+{
+  return nullptr;
+}
+
 } // namespace aria2
