@@ -33,11 +33,14 @@
  */
 /* copyright --> */
 
+// clang-format off
+
 #define TEXT_DIR                                                        \
   _(" -d, --dir=DIR                The directory to store the downloaded file.")
 #define TEXT_OUT                                                        \
-  _(" -o, --out=FILE               The file name of the downloaded file. When -Z\n"\
-    "                              option is used, this option is ignored.")
+  _(" -o, --out=FILE               The file name of the downloaded file. When \n" \
+    "                              the -Z option is used, this option will be \n" \
+    "                              ignored.")
 #define TEXT_LOG                                                        \
   _(" -l, --log=LOG                The file name of the log file. If '-' is\n" \
     "                              specified, log is written to stdout.")
@@ -48,16 +51,14 @@
     "                              \"/dev/null\".")
 #define TEXT_SPLIT                                                      \
   _(" -s, --split=N                Download a file using N connections. If more\n" \
-    "                              than N URLs are given, first N URLs are used and\n" \
+    "                              than N URIs are given, first N URIs are used and\n" \
     "                              remaining URLs are used for backup. If less than\n" \
-    "                              N URLs are given, those URLs are used more than\n" \
+    "                              N URIs are given, those URLs are used more than\n" \
     "                              once so that N connections total are made\n" \
     "                              simultaneously. The number of connections to the\n" \
-    "                              same host is restricted by\n"        \
-    "                              --max-connection-per-server option. Please see -j\n" \
-    "                              and --min-split-size option too.\n"  \
-    "                              Please note that in Metalink download, this\n" \
-    "                              option has no effect and use -C option instead.")
+    "                              same host is restricted by the \n"        \
+    "                              --max-connection-per-server option. See also the\n" \
+    "                              --min-split-size option.")
 #define TEXT_RETRY_WAIT                                                 \
   _(" --retry-wait=SEC             Set the seconds to wait between retries. \n" \
     "                              With SEC > 0, aria2 will retry download when the\n" \
@@ -67,28 +68,28 @@
 #define TEXT_MAX_TRIES                                                  \
   _(" -m, --max-tries=N            Set number of tries. 0 means unlimited.")
 #define TEXT_HTTP_PROXY                                                 \
-  _(" --http-proxy=PROXY           Use this proxy server for HTTP. To erase\n"\
+  _(" --http-proxy=PROXY           Use a proxy server for HTTP. To override a\n"\
     "                              previously defined proxy, use \"\".\n"   \
-    "                              See also  --all-proxy option.\n"     \
-    "                              This affects all URLs.")
+    "                              See also the --all-proxy option.\n"     \
+    "                              This affects all http downloads.")
 #define TEXT_HTTPS_PROXY                                                \
-  _(" --https-proxy=PROXY          Use this proxy server for HTTPS. To erase\n"  \
+  _(" --https-proxy=PROXY          Use a proxy server for HTTPS. To override a \n"  \
     "                              previously defined proxy, use \"\".\n" \
-    "                              See also  --all-proxy option.\n"     \
-    "                              This affects all URLs.")
+    "                              See also the --all-proxy option.\n"     \
+    "                              This affects all https downloads.")
 #define TEXT_FTP_PROXY                                                  \
-  _(" --ftp-proxy=PROXY            Use this proxy server for FTP. To erase previously\n"    \
-    "                              defined proxy, use \"\".\n" \
-    "                              See also  --all-proxy option.\n"     \
-    "                              This affects all URLs.")
-#define TEXT_ALL_PROXY                                                  \
-  _(" --all-proxy=PROXY            Use this proxy server for all protocols. To erase\n" \
+  _(" --ftp-proxy=PROXY            Use a proxy server for FTP. To override a \n" \
     "                              previously defined proxy, use \"\".\n" \
-    "                              You can override this setting and specify a\n" \
-    "                              proxy server for a particular protocol using\n" \
+    "                              See also the --all-proxy option.\n"     \
+    "                              This affects all ftp downloads.")
+#define TEXT_ALL_PROXY                                                  \
+  _(" --all-proxy=PROXY            Use a proxy server for all protocols. To override\n" \
+    "                              a previously defined proxy, use \"\".\n" \
+    "                              You also can override this setting and specify a\n" \
+    "                              proxy server for a particular protocol using the\n" \
     "                              --http-proxy, --https-proxy and --ftp-proxy\n" \
     "                              options.\n"                          \
-    "                              This affects all URLs.")
+    "                              This affects all downloads.")
 #define TEXT_HTTP_USER                                                  \
   _(" --http-user=USER             Set HTTP user. This affects all URLs.")
 #define TEXT_HTTP_PASSWD                                                \
@@ -96,7 +97,11 @@
 #define TEXT_PROXY_METHOD                                               \
   _(" --proxy-method=METHOD        Set the method to use in proxy request.")
 #define TEXT_REFERER                                                    \
-  _(" --referer=REFERER            Set Referer. This affects all URLs.")
+  _(" --referer=REFERER            Set an http referrrer (Referer). This affects\n" \
+    "                              all http/https downloads. If \"*\" is given,\n" \
+    "                              the download URI is also used as the referrer.\n" \
+    "                              This may be useful when used together with\n" \
+    "                              the -P option.")
 #define TEXT_FTP_USER                                                   \
   _(" --ftp-user=USER              Set FTP user. This affects all URLs.")
 #define TEXT_FTP_PASSWD                                                 \
@@ -139,12 +144,15 @@
     "                              takes almost same time as 'prealloc' and it\n" \
     "                              blocks aria2 entirely until allocation finishes.\n" \
     "                              'falloc' may not be available if your system\n" \
-    "                              doesn't have posix_fallocate() function.")
+    "                              doesn't have posix_fallocate() function.\n" \
+    "                              'trunc' uses ftruncate() system call or\n" \
+    "                              platform-specific counterpart to truncate a file\n" \
+    "                              to a specified length.")
 #define TEXT_NO_FILE_ALLOCATION_LIMIT                                   \
   _(" --no-file-allocation-limit=SIZE No file allocation is made for files whose\n" \
     "                              size is smaller than SIZE.\n"        \
     "                              You can append K or M(1K = 1024, 1M = 1024K).")
-# define TEXT_ENABLE_DIRECT_IO                                          \
+#define TEXT_ENABLE_DIRECT_IO                                          \
   _(" --enable-direct-io[=true|false] Enable directI/O, which lowers cpu usage while\n" \
     "                              allocating files.\n"                 \
     "                              Turn off if you encounter any error")
@@ -156,7 +164,7 @@
   _(" --allow-piece-length-change[=true|false] If false is given, aria2 aborts\n" \
     "                              download when a piece length is different from\n" \
     "                              one in a control file. If true is given, you can\n" \
-    "                              proceed but some download progress will be lost.")  
+    "                              proceed but some download progress will be lost.")
 #define TEXT_FORCE_SEQUENTIAL                                           \
   _(" -Z, --force-sequential[=true|false] Fetch URIs in the command-line sequentially\n" \
     "                              and download each URI in a separate session, like\n" \
@@ -219,6 +227,8 @@
   _(" -U, --user-agent=USER_AGENT  Set user agent for http(s) downloads.")
 #define TEXT_NO_NETRC                                           \
   _(" -n, --no-netrc[=true|false]  Disables netrc support.")
+#define TEXT_NETRC_PATH                                           \
+  _(" --netrc-path=FILE            Specify the path to the netrc file.")
 #define TEXT_INPUT_FILE                                                 \
   _(" -i, --input-file=FILE        Downloads URIs found in FILE. You can specify\n" \
     "                              multiple URIs for a single entity: separate\n" \
@@ -228,11 +238,26 @@
     "                              line of URI. This optional line must start with\n" \
     "                              one or more white spaces and have one option per\n" \
     "                              single line. See INPUT FILE section of man page\n" \
-    "                              for details.")
+    "                              for details. See also --deferred-input option.")
 #define TEXT_MAX_CONCURRENT_DOWNLOADS                                   \
   _(" -j, --max-concurrent-downloads=N Set maximum number of parallel downloads for\n" \
     "                              every static (HTTP/FTP) URL, torrent and metalink.\n" \
-    "                              See also -s and -C options.")
+    "                              See also --split and --optimize-concurrent-downloads options.")
+#define TEXT_OPTIMIZE_CONCURRENT_DOWNLOADS\
+  _(" --optimize-concurrent-downloads[=true|false|A:B] Optimizes the number of\n" \
+    "                              concurrent downloads according to the bandwidth\n" \
+    "                              available. aria2 uses the download speed observed\n" \
+    "                              in the previous downloads to adapt the number of\n" \
+    "                              downloads launched in parallel according to the\n" \
+    "                              rule N = A + B Log10(speed in Mbps). The\n" \
+    "                              coefficients A and B can be customized in the\n" \
+    "                              option arguments with A and B separated by a\n" \
+    "                              colon. The default values (A=5,B=25) lead to\n" \
+    "                              using typically 5 parallel downloads on 1Mbps\n" \
+    "                              networks and above 50 on 100Mbps networks. The\n" \
+    "                              number of parallel downloads remains constrained\n" \
+    "                              under the maximum defined by the\n" \
+    "                              max-concurrent-downloads parameter.")
 #define TEXT_LOAD_COOKIES                                               \
   _(" --load-cookies=FILE          Load Cookies from FILE using the Firefox3 format\n" \
     "                              and Mozilla/Firefox(1.x/2.x)/Netscape format.")
@@ -265,8 +290,9 @@
     "                              mentioned in it.\n"                  \
     "                              If mem is specified, a torrent file is not\n" \
     "                              written to the disk, but is just kept in memory.\n" \
-    "                              If false is specified, the action mentioned above\n" \
-    "                              is not taken.")
+    "                              If false is specified, the .torrent file is\n" \
+    "                              downloaded to the disk, but is not parsed as a\n" \
+    "                              torrent and its contents are not downloaded.")
 #define TEXT_LISTEN_PORT                                                \
   _(" --listen-port=PORT...        Set TCP port number for BitTorrent downloads.\n" \
     "                              Multiple ports can be specified by using ',',\n" \
@@ -306,13 +332,16 @@
 #define TEXT_ENABLE_PEER_EXCHANGE                                       \
   _(" --enable-peer-exchange[=true|false] Enable Peer Exchange extension.")
 #define TEXT_ENABLE_DHT                                         \
-  _(" --enable-dht[=true|false]    Enable IPv4 DHT functionality.")
+  _(" --enable-dht[=true|false]    Enable IPv4 DHT functionality. It also enables\n" \
+    "                              UDP tracker support. If a private flag is set\n" \
+    "                              in a torrent, aria2 doesn't use DHT for that\n" \
+    "                              download even if ``true`` is given.")
 #define TEXT_DHT_LISTEN_PORT                                            \
-  _(" --dht-listen-port=PORT...    Set UDP listening port for both IPv4 and IPv6\n"   \
-    "                              DHT. Multiple ports can be specified by using\n" \
-    "                              ',', for example: \"6881,6885\". You can also\n" \
-    "                              use '-' to specify a range: \"6881-6999\". ','\n" \
-    "                              and '-' can be used together.")
+  _(" --dht-listen-port=PORT...    Set UDP listening port used by DHT(IPv4, IPv6)\n"   \
+    "                              and UDP tracker. Multiple ports can be specified\n" \
+    "                              by using ',', for example: \"6881,6885\". You can\n" \
+    "                              also use '-' to specify a range: \"6881-6999\".\n" \
+    "                              ',' and '-' can be used together.")
 #define TEXT_DHT_ENTRY_POINT                                            \
   _(" --dht-entry-point=HOST:PORT  Set host and port as an entry point to IPv4 DHT\n" \
     "                              network.")
@@ -337,8 +366,9 @@
     "                              download speed in some cases.\n"     \
     "                              You can append K or M(1K = 1024, 1M = 1024K).")
 #define TEXT_BT_MAX_OPEN_FILES                                          \
-  _(" --bt-max-open-files=NUM      Specify maximum number of files to open in each\n" \
-    "                              BitTorrent download.")
+  _(" --bt-max-open-files=NUM      Specify maximum number of files to open in\n" \
+    "                              multi-file BitTorrent/Metalink downloads\n" \
+    "                              globally.")
 #define TEXT_BT_SEED_UNVERIFIED                                         \
   _(" --bt-seed-unverified[=true|false] Seed previously downloaded files without\n" \
     "                              verifying piece hashes.")
@@ -381,8 +411,10 @@
     "                              mentioned in it.\n"                  \
     "                              If mem is specified, a metalink file is not\n" \
     "                              written to the disk, but is just kept in memory.\n" \
-    "                              If false is specified, the action mentioned above\n" \
-    "                              is not taken.")
+    "                              If false is specified, the .metalink file is\n" \
+    "                              downloaded to the disk, but is not parsed as a\n" \
+    "                              metalink file and its contents are not\n" \
+    "                              downloaded.")
 #define TEXT_METALINK_ENABLE_UNIQUE_PROTOCOL                            \
   _(" --metalink-enable-unique-protocol[=true|false] If true is given and several\n" \
     "                              protocols are available for a mirror in a metalink\n" \
@@ -421,7 +453,8 @@
   _(" --summary-interval=SEC       Set interval to output download progress summary.\n" \
     "                              Setting 0 suppresses the output.")
 #define TEXT_LOG_LEVEL                                          \
-  _(" --log-level=LEVEL            Set log level to output.")
+  _(" --log-level=LEVEL            Set log level to output to file specified using\n" \
+    "                             --log option.")
 #define TEXT_REMOTE_TIME                                                \
   _(" -R, --remote-time[=true|false] Retrieve timestamp of the remote file from the\n" \
     "                              remote HTTP/FTP server and if it is available,\n" \
@@ -437,7 +470,9 @@
     "                              a single byte, then force the download to fail.\n" \
     "                              Specify 0 to disable this option.\n" \
     "                              This options is effective only when using\n" \
-    "                              HTTP/FTP servers.")
+    "                              HTTP/FTP servers. The number of retry attempt is\n" \
+    "                              counted toward --max-tries, so it should be\n" \
+    "                              configured too.")
 #define TEXT_URI_SELECTOR                                               \
   _(" --uri-selector=SELECTOR      Specify URI selection algorithm.\n"  \
     "                              If 'inorder' is given, URI is tried in the order\n" \
@@ -585,6 +620,13 @@
 #define TEXT_INTERFACE                                                  \
   _(" --interface=INTERFACE        Bind sockets to given interface. You can specify\n" \
     "                              interface name, IP address and hostname.")
+#define TEXT_MULTIPLE_INTERFACE                                         \
+  _(" --multiple-interface=INTERFACES Comma separated list of interfaces to bind\n" \
+    "                              sockets to. Requests will be splited among the\n" \
+    "                              interfaces to achieve link aggregation. You can\n" \
+    "                              specify interface name, IP address and hostname.\n" \
+    "                              If --interface is used, this option will be\n" \
+    "                              ignored.")
 #define TEXT_DISABLE_IPV6                               \
   _(" --disable-ipv6[=true|false]  Disable IPv6.")
 #define TEXT_BT_SAVE_METADATA                                           \
@@ -620,21 +662,21 @@
   _(" --reuse-uri[=true|false]     Reuse already used URIs if no unused URIs are\n" \
     "                              left.")
 #define TEXT_ALL_PROXY_USER                                             \
-  _(" --all-proxy-user=USER        Set user for --all-proxy option.")
+  _(" --all-proxy-user=USER        Set user for --all-proxy.")
 #define TEXT_ALL_PROXY_PASSWD                                           \
-  _(" --all-proxy-passwd=PASSWD    Set password for --all-proxy option.")
+  _(" --all-proxy-passwd=PASSWD    Set password for --all-proxy.")
 #define TEXT_HTTP_PROXY_USER                                            \
-  _(" --http-proxy-user=USER       Set user for --http-proxy option.")
+  _(" --http-proxy-user=USER       Set user for --http-proxy.")
 #define TEXT_HTTP_PROXY_PASSWD                                          \
-  _(" --http-proxy-passwd=PASSWD   Set password for --http-proxy option.")
+  _(" --http-proxy-passwd=PASSWD   Set password for --http-proxy.")
 #define TEXT_HTTPS_PROXY_USER                                           \
-  _(" --https-proxy-user=USER      Set user for --https-proxy option.")
+  _(" --https-proxy-user=USER      Set user for --https-proxy.")
 #define TEXT_HTTPS_PROXY_PASSWD                                         \
-  _(" --https-proxy-passwd=PASSWD  Set password for --https-proxy option.")
+  _(" --https-proxy-passwd=PASSWD  Set password for --https-proxy.")
 #define TEXT_FTP_PROXY_USER                                             \
-  _(" --ftp-proxy-user=USER        Set user for --ftp-proxy option.")
+  _(" --ftp-proxy-user=USER        Set user for --ftp-proxy.")
 #define TEXT_FTP_PROXY_PASSWD                                           \
-  _(" --ftp-proxy-passwd=PASSWD    Set password for --ftp-proxy option.")
+  _(" --ftp-proxy-passwd=PASSWD    Set password for --ftp-proxy.")
 #define TEXT_REMOVE_CONTROL_FILE                \
   _(" --remove-control-file[=true|false] Remove control file before download. Using\n" \
     "                              with --allow-overwrite=true, download always\n" \
@@ -759,19 +801,23 @@
     "                              option is useful when the system does not have\n" \
     "                              /etc/resolv.conf and user does not have the\n" \
     "                              permission to create it.")
-#define TEXT_ENABLE_RPC                                             \
-  _(" --enable-rpc[=true|false]    Enable JSON-RPC/XML-RPC server.\n"   \
-    "                              It is strongly recommended to set username and\n" \
-    "                              password using --rpc-user and --rpc-passwd\n" \
-    "                              option. See also --rpc-listen-port option.")
+#define TEXT_ENABLE_RPC                                               \
+  _(" --enable-rpc[=true|false]    Enable JSON-RPC/XML-RPC server.\n" \
+    "                              It is strongly recommended to set secret\n" \
+    "                              authorization token using --rpc-secret option.\n" \
+    "                              See also --rpc-listen-port option.")
 #define TEXT_RPC_MAX_REQUEST_SIZE                                   \
   _(" --rpc-max-request-size=SIZE  Set max size of JSON-RPC/XML-RPC request. If aria2\n" \
     "                              detects the request is more than SIZE bytes, it\n" \
     "                              drops connection.")
 #define TEXT_RPC_USER                               \
-  _(" --rpc-user=USER              Set JSON-RPC/XML-RPC user.")
+  _(" --rpc-user=USER              Set JSON-RPC/XML-RPC user. This option will be\n" \
+    "                              deprecated in the future release. Migrate to\n" \
+    "                              --rpc-secret option as soon as possible.")
 #define TEXT_RPC_PASSWD                                     \
-  _(" --rpc-passwd=PASSWD          Set JSON-RPC/XML-RPC password.")
+  _(" --rpc-passwd=PASSWD          Set JSON-RPC/XML-RPC password. This option will\n" \
+    "                              be deprecated in the future release. Migrate to\n" \
+    "                              --rpc-secret option as soon as possible.")
 #define TEXT_RPC_LISTEN_ALL                                         \
   _(" --rpc-listen-all[=true|false] Listen incoming JSON-RPC/XML-RPC requests on all\n" \
     "                              network interfaces. If false is given, listen only\n" \
@@ -805,6 +851,9 @@
     "                              --min-split-size option, so it will be necessary\n" \
     "                              to specify a reasonable value to\n"  \
     "                              --min-split-size option.\n"          \
+    "                              If 'random' is given, aria2 selects piece\n" \
+    "                              randomly. Like 'inorder', --min-split-size\n" \
+    "                              option is honored.\n"                \
     "                              If 'geom' is given, at the beginning aria2\n" \
     "                              selects piece which has minimum index like\n" \
     "                              'inorder', but it exponentially increasingly\n" \
@@ -854,3 +903,186 @@
     "                              option will be ignored in BitTorrent downloads.\n" \
     "                              It will be also ignored if Metalink file\n" \
     "                              contains piece hashes.")
+#define TEXT_STOP_WITH_PROCESS                                          \
+  _(" --stop-with-process=PID      Stop application when process PID is not running.\n" \
+    "                              This is useful if aria2 process is forked from a\n" \
+    "                              parent process. The parent process can fork aria2\n" \
+    "                              with its own pid and when parent process exits\n" \
+    "                              for some reason, aria2 can detect it and shutdown\n" \
+    "                              itself.")
+#define TEXT_DEFERRED_INPUT                     \
+  _(" --deferred-input[=true|false] If true is given, aria2 does not read all URIs\n" \
+    "                              and options from file specified by -i option at\n" \
+    "                              startup, but it reads one by one when it needs\n" \
+    "                              later. This may reduce memory usage if input\n" \
+    "                              file contains a lot of URIs to download.\n" \
+    "                              If false is given, aria2 reads all URIs and\n" \
+    "                              options at startup.")
+#define TEXT_BT_REMOVE_UNSELECTED_FILE                                  \
+  _(" --bt-remove-unselected-file[=true|false] Removes the unselected files when\n" \
+    "                              download is completed in BitTorrent. To\n" \
+    "                              select files, use --select-file option. If\n" \
+    "                              it is not used, all files are assumed to be\n" \
+    "                              selected. Please use this option with care\n" \
+    "                              because it will actually remove files from\n" \
+    "                              your disk.")
+#define TEXT_ENABLE_MMAP                        \
+  _(" --enable-mmap[=true|false]   Map files into memory.")
+#define TEXT_RPC_CERTIFICATE                                            \
+  _(" --rpc-certificate=FILE       Use the certificate in FILE for RPC server.\n" \
+    "                              The certificate must be in PEM format.\n" \
+    "                              Use --rpc-private-key option to specify the\n" \
+    "                              private key. Use --rpc-secure option to enable\n" \
+    "                              encryption.")
+#define TEXT_RPC_PRIVATE_KEY                                            \
+  _(" --rpc-private-key=FILE       Use the private key in FILE for RPC server.\n" \
+    "                              The private key must be decrypted and in PEM\n" \
+    "                              format. Use --rpc-secure option to enable\n" \
+    "                              encryption. See also --rpc-certificate option.")
+#define TEXT_RPC_SECURE                         \
+  _(" --rpc-secure[=true|false]    RPC transport will be encrypted by SSL/TLS.\n" \
+    "                              The RPC clients must use https scheme to access\n" \
+    "                              the server. For WebSocket client, use wss\n" \
+    "                              scheme. Use --rpc-certificate and\n" \
+    "                              --rpc-private-key options to specify the\n" \
+    "                              server certificate and private key.")
+#define TEXT_RPC_SAVE_UPLOAD_METADATA                                   \
+  _(" --rpc-save-upload-metadata[=true|false] Save the uploaded torrent or\n" \
+    "                              metalink metadata in the directory specified\n" \
+    "                              by --dir option. The filename consists of\n" \
+    "                              SHA-1 hash hex string of metadata plus\n" \
+    "                              extension. For torrent, the extension is\n" \
+    "                              '.torrent'. For metalink, it is '.meta4'.\n" \
+    "                              If false is given to this option, the\n" \
+    "                              downloads added by aria2.addTorrent or\n" \
+    "                              aria2.addMetalink will not be saved by\n" \
+    "                              --save-session option.")
+#define TEXT_FORCE_SAVE                         \
+  _(" --force-save[=true|false]    Save download with --save-session option even\n" \
+    "                              if the download is completed or removed. This\n" \
+    "                              option also saves control file in that\n" \
+    "                              situations. This may be useful to save\n" \
+    "                              BitTorrent seeding which is recognized as\n" \
+    "                              completed state.")
+#define TEXT_DISK_CACHE                         \
+  _(" --disk-cache=SIZE            Enable disk cache. If SIZE is 0, the disk cache\n" \
+    "                              is disabled. This feature caches the downloaded\n" \
+    "                              data in memory, which grows to at most SIZE\n" \
+    "                              bytes. The cache storage is created for aria2\n" \
+    "                              instance and shared by all downloads. The one\n" \
+    "                              advantage of the disk cache is reduce the disk\n" \
+    "                              I/O because the data are written in larger unit\n" \
+    "                              and it is reordered by the offset of the file.\n" \
+    "                              If hash checking is involved and the data are\n" \
+    "                              cached in memory, we don't need to read them\n" \
+    "                              from the disk.\n"                    \
+    "                              SIZE can include K or M(1K = 1024, 1M = 1024K).")
+#define TEXT_GID                                \
+  _(" --gid=GID                    Set GID manually. aria2 identifies each\n" \
+    "                              download by the ID called GID. The GID must be\n" \
+    "                              hex string of 16 characters, thus [0-9a-zA-Z]\n" \
+    "                              are allowed and leading zeros must not be\n" \
+    "                              stripped. The GID all 0 is reserved and must\n" \
+    "                              not be used. The GID must be unique, otherwise\n" \
+    "                              error is reported and the download is not added.\n" \
+    "                              This option is useful when restoring the\n" \
+    "                              sessions saved using --save-session option. If\n" \
+    "                              this option is not used, new GID is generated\n" \
+    "                              by aria2.")
+#define TEXT_CONSOLE_LOG_LEVEL                                          \
+  _(" --console-log-level=LEVEL    Set log level to output to console.")
+#define TEXT_SAVE_SESSION_INTERVAL                                      \
+  _(" --save-session-interval=SEC  Save error/unfinished downloads to a file\n" \
+    "                              specified by --save-session option every SEC\n" \
+    "                              seconds. If 0 is given, file will be saved only\n" \
+    "                              when aria2 exits.")
+#define TEXT_ENABLE_COLOR                                               \
+  _(" --enable-color[=true|false]  Enable color output for a terminal.")
+#define TEXT_RPC_SECRET                                                 \
+  _(" --rpc-secret=TOKEN           Set RPC secret authorization token.")
+#define TEXT_DSCP                                                       \
+  _(" --dscp=DSCP                  Set DSCP value in outgoing IP packets of\n" \
+    "                              BitTorrent traffic for QoS. This parameter sets\n" \
+    "                              only DSCP bits in TOS field of IP packets,\n" \
+    "                              not the whole field. If you take values\n" \
+    "                              from /usr/include/netinet/ip.h divide them by 4\n" \
+    "                              (otherwise values would be incorrect, e.g. your\n" \
+    "                              CS1 class would turn into CS4). If you take\n" \
+    "                              commonly used values from RFC, network vendors'\n" \
+    "                              documentation, Wikipedia or any other source,\n" \
+    "                              use them as they are.")
+#define TEXT_RLIMIT_NOFILE                                              \
+  _(" --rlimit-nofile=NUM          Set the soft limit of open file descriptors.\n" \
+    "                              This open will only have effect when:\n" \
+    "                                a) The system supports it (posix)\n" \
+    "                                b) The limit does not exceed the hard limit.\n" \
+    "                                c) The specified limit is larger than the\n" \
+    "                                   current soft limit.\n" \
+    "                              This is equivalent to setting nofile via ulimit,\n" \
+    "                              except that it will never decrease the limit.")
+#define TEXT_PAUSE_METADATA                  \
+  _(" --pause-metadata[=true|false]\n"       \
+    "                              Pause downloads created as a result of metadata\n" \
+    "                              download. There are 3 types of metadata\n" \
+    "                              downloads in aria2: (1) downloading .torrent\n" \
+    "                              file. (2) downloading torrent metadata using\n" \
+    "                              magnet link. (3) downloading metalink file.\n" \
+    "                              These metadata downloads will generate downloads\n" \
+    "                              using their metadata. This option pauses these\n" \
+    "                              subsequent downloads. This option is effective\n" \
+    "                              only when --enable-rpc=true is given.")
+#define TEXT_BT_DETACH_SEED_ONLY                \
+  _(" --bt-detach-seed-only[=true|false]\n"     \
+    "                              Exclude seed only downloads when counting\n" \
+    "                              concurrent active downloads (See -j option).\n" \
+    "                              This means that if -j3 is given and this option\n" \
+    "                              is turned on and 3 downloads are active and one\n" \
+    "                              of those enters seed mode, then it is excluded\n" \
+    "                              from active download count (thus it becomes 2),\n" \
+    "                              and the next download waiting in queue gets\n" \
+    "                              started. But be aware that seeding item is still\n" \
+    "                              recognized as active download in RPC method.")
+#define TEXT_MIN_TLS_VERSION                                            \
+  _(" --min-tls-version=VERSION    Specify minimum SSL/TLS version to enable.")
+#define TEXT_BT_FORCE_ENCRYPTION                                        \
+  _(" --bt-force-encryption[=true|false]\n"                             \
+    "                              Requires BitTorrent message payload encryption\n" \
+    "                              with arc4. This is a shorthand of\n" \
+    "                              --bt-require-crypto --bt-min-crypto-level=arc4.\n" \
+    "                              If true is given, deny legacy BitTorrent\n" \
+    "                              handshake and only use Obfuscation handshake and\n" \
+    "                              always encrypt message payload.")
+#define TEXT_SSH_HOST_KEY_MD                                            \
+  _(" --ssh-host-key-md=TYPE=DIGEST\n"                                  \
+    "                              Set checksum for SSH host public key. TYPE is\n" \
+    "                              hash type. The supported hash type is sha-1 or\n" \
+    "                              md5. DIGEST is hex digest. For example:\n" \
+    "                              sha-1=b030503d4de4539dc7885e6f0f5e256704edf4c3\n" \
+    "                              This option can be used to validate server's\n" \
+    "                              public key when SFTP is used. If this option is\n" \
+    "                              not set, which is default, no validation takes\n" \
+    "                              place.")
+#define TEXT_SOCKET_RECV_BUFFER_SIZE                                    \
+  _(" --socket-recv-buffer-size=SIZE\n"                                 \
+    "                              Set the maximum socket receive buffer in bytes.\n" \
+    "                              Specifing 0 will disable this option. This value\n" \
+    "                              will be set to socket file descriptor using\n" \
+    "                              SO_RCVBUF socket option with setsockopt() call.")
+#define TEXT_BT_ENABLE_HOOK_AFTER_HASH_CHECK                            \
+  _(" --bt-enable-hook-after-hash-check[=true|false] Allow hook command invocation\n" \
+    "                              after hash check (see -V option) in BitTorrent\n" \
+    "                              download. By default, when hash check succeeds,\n" \
+    "                              the command given by --on-bt-download-complete\n" \
+    "                              is executed. To disable this action, give false\n" \
+    "                              to this option.")
+#define TEXT_MAX_MMAP_LIMIT                                             \
+  _(" --max-mmap-limit=SIZE        Set the maximum file size to enable mmap (see\n" \
+    "                              --enable-mmap option). The file size is\n" \
+    "                              determined by the sum of all files contained in\n" \
+    "                              one download. For example, if a download\n" \
+    "                              contains 5 files, then file size is the total\n" \
+    "                              size of those files. If file size is strictly\n" \
+    "                              greater than the size specified in this option,\n" \
+    "                              mmap will be disabled.")
+
+// clang-format on
